@@ -7,7 +7,7 @@ import re
 
 
 def is_email(mailaddress: str) -> bool:
-    u"""Very basic check if the email address has a valid format."""
+    """Very basic check if the email address has a valid format."""
 
     if mailaddress is None or mailaddress == '':
         logging.warning('No mail address supplied.')
